@@ -14,6 +14,8 @@ def _get_connection():
         'host': settings.REDIS_HOST,
         'port': settings.REDIS_PORT,
         'db': settings.REDIS_DB,
+        'url': settings.REDIS_URL,
+        'password': settings.REDIS_PASSWORD,
     })())
 
     return get_current_connection()
@@ -22,8 +24,10 @@ def _get_connection():
 class RqBackend(BaseEmailBackend):
     def send_messages(self, email_messages):
 
+        connection = get_connection()
+
         for message in email_messages:
-            enqueue(manage_message, message, connection=get_connection())
+            enqueue(manage_message, message, connection=connection)
 
         return len(email_messages)
 
